@@ -3,8 +3,8 @@
 ;; Description: Message Harmonized Calendaring system.
 ;; Author:  Yoshinari Nomura <nom@quickhack.net>
 ;; Created: 1994-07-04
-;; Package-Version: 1.2.7
-;; Package-Revision: v1.2.7-0-gb527a8874865
+;; Package-Version: 20250904.940
+;; Package-Revision: 2e5e62603637
 ;; Keywords: calendar
 ;; URL: http://www.quickhack.net/mhc
 ;; Package-Requires: ((calfw "20150703"))
@@ -49,6 +49,8 @@
 (require 'mhc-face)
 (require 'mhc-calendar)
 (require 'mhc-draft)
+(require 'mhc-header)
+(require 'mhc-compat)
 
 (cond
  ((eval-when-compile  (and (not (featurep 'xemacs))
@@ -575,7 +577,9 @@ If optional NAME is non-nil, created smmary buffer has the name."
   "Search events by STRING.
 If SUBJECT-ONLY is non-nil, it will search only on X-SC-Subject:"
   (interactive "sSearch: \nP")
-  (let* ((match (mhc-db-search :subject string :body (unless subject-only string))))
+  (let* ((match (mhc-db-search :subject string
+                               :body (unless subject-only string)
+                               :location (unless subject-only string))))
     (if (null match)
         (message "No match")
       (mhc-scan match))))
